@@ -23,7 +23,6 @@ import time
 
 from oslo_concurrency import processutils as putils
 from oslo_log import log as logging
-import six
 
 from os_brick import exception
 from os_brick import executor
@@ -288,11 +287,12 @@ class LinuxSCSI(executor.Executor):
         # instead it maps to /dev/mapped/crypt-XYZ
         return not was_multipath and '/dev' != os.path.split(path_used)[0]
 
-    def remove_connection(self, devices_names, force=False, exc=None,
-                          path_used=None, was_multipath=False):
+    def remove_connection(self, devices_names, is_multipath, force=False,
+                          exc=None, path_used=None, was_multipath=False):
         """Remove LUNs and multipath associated with devices names.
 
         :param devices_names: Iterable with real device names ('sda', 'sdb')
+        :param is_multipath: Whether this is a multipath connection or not
         :param force: Whether to forcefully disconnect even if flush fails.
         :param exc: ExceptionChainer where to add exceptions if forcing
         :param path_used: What path was used by Nova/Cinder for I/O
@@ -301,32 +301,22 @@ class LinuxSCSI(executor.Executor):
         """
         if not devices_names:
             return
+        multipath_name = None
         exc = exception.ExceptionChainer() if exc is None else exc
-
-        multipath_dm = self.find_sysfs_multipath_dm(devices_names)
         LOG.debug('Removing %(type)s devices %(devices)s',
-                  {'type': 'multipathed' if multipath_dm else 'single pathed',
+                  {'type': 'multipathed' if is_multipath else 'single pathed',
                    'devices': ', '.join(devices_names)})
-        multipath_name = multipath_dm and self.get_dm_name(multipath_dm)
-        if multipath_name:
-            with exc.context(force, 'Flushing %s failed', multipath_name):
-                self.flush_multipath_device(multipath_name)
-                multipath_name = None
-            multipath_running = True
-        else:
-            multipath_running = self.is_multipath_running(
-                enforce_multipath=False, root_helper=self._root_helper)
+
+        if is_multipath:
+            multipath_dm = self.find_sysfs_multipath_dm(devices_names)
+            multipath_name = multipath_dm and self.get_dm_name(multipath_dm)
+            if multipath_name:
+                with exc.context(force, 'Flushing %s failed', multipath_name):
+                    self.flush_multipath_device(multipath_name)
+                    multipath_name = None
 
         for device_name in devices_names:
             dev_path = '/dev/' + device_name
-            if multipath_running:
-                # Recent multipathd doesn't remove path devices in time when
-                # it receives mutiple udev events in a short span, so here we
-                # tell multipathd to remove the path device immediately.
-                # Even if this step fails, later removing an iscsi device
-                # triggers a udev event and multipathd can remove the path
-                # device based on the udev event
-                self.multipath_del_path(dev_path)
             flush = self.requires_flush(dev_path, path_used, was_multipath)
             self.remove_scsi_device(dev_path, force, exc, flush)
 
@@ -555,7 +545,7 @@ class LinuxSCSI(executor.Executor):
         (out, _err) = self._execute('blockdev', '--getsize64',
                                     device, run_as_root=True,
                                     root_helper=self._root_helper)
-        var = six.text_type(out.strip())
+        var = str(out.strip())
         if var.isnumeric():
             return int(var)
         else:
@@ -735,11 +725,3 @@ class LinuxSCSI(executor.Executor):
                                        check_exit_code=False,
                                        root_helper=self._root_helper)
         return stdout.strip() == 'ok'
-
-    def multipath_del_path(self, realpath):
-        """Remove a path from multipathd for monitoring."""
-        stdout, stderr = self._execute('multipathd', 'del', 'path', realpath,
-                                       run_as_root=True, timeout=5,
-                                       check_exit_code=False,
-                                       root_helper=self._root_helper)
-        return stdout.strip() == 'ok'
