@@ -142,7 +142,7 @@ class LinuxSCSITestCase(base.TestCase):
         wwn = self.linuxscsi.get_scsi_wwn(fake_path)
         self.assertEqual(fake_wwn, wwn)
 
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_dm_name(self, open_mock):
         dm_map_name = '3600d0230000000000e13955cc3757800'
         cm_open = open_mock.return_value.__enter__.return_value
@@ -151,7 +151,7 @@ class LinuxSCSITestCase(base.TestCase):
         self.assertEqual(dm_map_name, res)
         open_mock.assert_called_once_with('/sys/block/dm-0/dm/name')
 
-    @mock.patch('six.moves.builtins.open', side_effect=IOError)
+    @mock.patch('builtins.open', side_effect=IOError)
     def test_get_dm_name_failure(self, open_mock):
         self.assertEqual('', self.linuxscsi.get_dm_name('dm-0'))
 
@@ -229,20 +229,15 @@ class LinuxSCSITestCase(base.TestCase):
               {'do_raise': True, 'force': True})
     @ddt.unpack
     @mock.patch.object(linuxscsi.LinuxSCSI, '_remove_scsi_symlinks')
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'multipath_del_path')
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'is_multipath_running',
-                       return_value=True)
     @mock.patch.object(linuxscsi.LinuxSCSI, 'flush_multipath_device')
     @mock.patch.object(linuxscsi.LinuxSCSI, 'get_dm_name')
     @mock.patch.object(linuxscsi.LinuxSCSI, 'find_sysfs_multipath_dm')
     @mock.patch.object(linuxscsi.LinuxSCSI, 'wait_for_volumes_removal')
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'remove_scsi_device')
+    @mock.patch('os_brick.initiator.linuxscsi.LinuxSCSI.remove_scsi_device')
     def test_remove_connection_multipath_complete(self, remove_mock, wait_mock,
                                                   find_dm_mock,
                                                   get_dm_name_mock,
                                                   flush_mp_mock,
-                                                  is_mp_running_mock,
-                                                  mp_del_path_mock,
                                                   remove_link_mock,
                                                   do_raise, force):
         if do_raise:
@@ -250,6 +245,7 @@ class LinuxSCSITestCase(base.TestCase):
         devices_names = ('sda', 'sdb')
         exc = exception.ExceptionChainer()
         mp_name = self.linuxscsi.remove_connection(devices_names,
+                                                   is_multipath=True,
                                                    force=mock.sentinel.Force,
                                                    exc=exc)
         find_dm_mock.assert_called_once_with(devices_names)
@@ -257,9 +253,6 @@ class LinuxSCSITestCase(base.TestCase):
         flush_mp_mock.assert_called_once_with(get_dm_name_mock.return_value)
         self.assertEqual(get_dm_name_mock.return_value if do_raise else None,
                          mp_name)
-        is_mp_running_mock.assert_not_called()
-        mp_del_path_mock.assert_has_calls([
-            mock.call('/dev/sda'), mock.call('/dev/sdb')])
         remove_mock.assert_has_calls([
             mock.call('/dev/sda', mock.sentinel.Force, exc, False),
             mock.call('/dev/sdb', mock.sentinel.Force, exc, False)])
@@ -268,46 +261,6 @@ class LinuxSCSITestCase(base.TestCase):
         remove_link_mock.assert_called_once_with(devices_names)
 
     @mock.patch.object(linuxscsi.LinuxSCSI, '_remove_scsi_symlinks')
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'multipath_del_path')
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'is_multipath_running',
-                       return_value=True)
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'flush_multipath_device')
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'get_dm_name')
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'find_sysfs_multipath_dm',
-                       return_value=None)
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'wait_for_volumes_removal')
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'remove_scsi_device')
-    def test_remove_connection_multipath_complete_no_dm(self, remove_mock,
-                                                        wait_mock,
-                                                        find_dm_mock,
-                                                        get_dm_name_mock,
-                                                        flush_mp_mock,
-                                                        is_mp_running_mock,
-                                                        mp_del_path_mock,
-                                                        remove_link_mock):
-        devices_names = ('sda', 'sdb')
-        exc = exception.ExceptionChainer()
-        mp_name = self.linuxscsi.remove_connection(devices_names,
-                                                   force=mock.sentinel.Force,
-                                                   exc=exc)
-        find_dm_mock.assert_called_once_with(devices_names)
-        get_dm_name_mock.assert_not_called()
-        flush_mp_mock.assert_not_called()
-        self.assertIsNone(mp_name)
-        is_mp_running_mock.assert_called_once()
-        mp_del_path_mock.assert_has_calls([
-            mock.call('/dev/sda'), mock.call('/dev/sdb')])
-        remove_mock.assert_has_calls([
-            mock.call('/dev/sda', mock.sentinel.Force, exc, False),
-            mock.call('/dev/sdb', mock.sentinel.Force, exc, False)])
-        wait_mock.assert_called_once_with(devices_names)
-        self.assertFalse(bool(exc))
-        remove_link_mock.assert_called_once_with(devices_names)
-
-    @mock.patch.object(linuxscsi.LinuxSCSI, '_remove_scsi_symlinks')
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'multipath_del_path')
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'is_multipath_running',
-                       return_value=True)
     @mock.patch.object(linuxscsi.LinuxSCSI, 'flush_multipath_device',
                        side_effect=Exception)
     @mock.patch.object(linuxscsi.LinuxSCSI, 'get_dm_name')
@@ -316,51 +269,32 @@ class LinuxSCSITestCase(base.TestCase):
     @mock.patch.object(linuxscsi.LinuxSCSI, 'remove_scsi_device')
     def test_remove_connection_multipath_fail(self, remove_mock, wait_mock,
                                               find_dm_mock, get_dm_name_mock,
-                                              flush_mp_mock,
-                                              is_mp_running_mock,
-                                              mp_del_path_mock,
-                                              remove_link_mock):
+                                              flush_mp_mock, remove_link_mock):
         flush_mp_mock.side_effect = exception.ExceptionChainer
         devices_names = ('sda', 'sdb')
         exc = exception.ExceptionChainer()
         self.assertRaises(exception.ExceptionChainer,
                           self.linuxscsi.remove_connection,
-                          devices_names, force=False, exc=exc)
+                          devices_names, is_multipath=True,
+                          force=False, exc=exc)
         find_dm_mock.assert_called_once_with(devices_names)
         get_dm_name_mock.assert_called_once_with(find_dm_mock.return_value)
         flush_mp_mock.assert_called_once_with(get_dm_name_mock.return_value)
-        is_mp_running_mock.assert_not_called()
-        mp_del_path_mock.assert_not_called()
         remove_mock.assert_not_called()
         wait_mock.assert_not_called()
         remove_link_mock.assert_not_called()
         self.assertTrue(bool(exc))
 
     @mock.patch.object(linuxscsi.LinuxSCSI, '_remove_scsi_symlinks')
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'multipath_del_path')
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'is_multipath_running',
-                       return_value=True)
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'find_sysfs_multipath_dm')
     @mock.patch.object(linuxscsi.LinuxSCSI, 'wait_for_volumes_removal')
     @mock.patch.object(linuxscsi.LinuxSCSI, 'remove_scsi_device')
-    def test_remove_connection_singlepath_no_path(self, remove_mock, wait_mock,
-                                                  find_dm_mock,
-                                                  is_mp_running_mock,
-                                                  mp_del_path_mock,
-                                                  remove_link_mock):
-        # Test remove connection when we didn't form a multipath and didn't
-        # even use any of the devices that were found.  This means that we
-        # don't flush any of the single paths when removing them.
-        find_dm_mock.return_value = None
+    def test_remove_connection_singlepath(self, remove_mock, wait_mock,
+                                          remove_link_mock):
         devices_names = ('sda', 'sdb')
         exc = exception.ExceptionChainer()
-        self.linuxscsi.remove_connection(devices_names,
+        self.linuxscsi.remove_connection(devices_names, is_multipath=False,
                                          force=mock.sentinel.Force,
                                          exc=exc)
-        find_dm_mock.assert_called_once_with(devices_names)
-        is_mp_running_mock.assert_called_once()
-        mp_del_path_mock.assert_has_calls([
-            mock.call('/dev/sda'), mock.call('/dev/sdb')])
         remove_mock.assert_has_calls(
             [mock.call('/dev/sda', mock.sentinel.Force, exc, False),
              mock.call('/dev/sdb', mock.sentinel.Force, exc, False)])
@@ -368,33 +302,19 @@ class LinuxSCSITestCase(base.TestCase):
         remove_link_mock.assert_called_once_with(devices_names)
 
     @mock.patch.object(linuxscsi.LinuxSCSI, '_remove_scsi_symlinks')
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'multipath_del_path')
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'is_multipath_running',
-                       return_value=False)
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'find_sysfs_multipath_dm')
     @mock.patch.object(linuxscsi.LinuxSCSI, 'wait_for_volumes_removal')
     @mock.patch.object(linuxscsi.LinuxSCSI, 'remove_scsi_device')
     def test_remove_connection_singlepath_used(self, remove_mock, wait_mock,
-                                               find_dm_mock,
-                                               is_mp_running_mock,
-                                               mp_del_path_mock,
                                                remove_link_mock):
-        # Test remove connection when we didn't form a multipath and just used
-        # one of the single paths that were found.  This means that we don't
-        # flush any of the single paths when removing them.
-        find_dm_mock.return_value = None
         devices_names = ('sda', 'sdb')
         exc = exception.ExceptionChainer()
 
         # realpath was mocked on test setup
         with mock.patch('os.path.realpath', side_effect=self.realpath):
-            self.linuxscsi.remove_connection(devices_names,
+            self.linuxscsi.remove_connection(devices_names, is_multipath=True,
                                              force=mock.sentinel.Force,
                                              exc=exc, path_used='/dev/sdb',
                                              was_multipath=False)
-        find_dm_mock.assert_called_once_with(devices_names)
-        is_mp_running_mock.assert_called_once()
-        mp_del_path_mock.assert_not_called()
         remove_mock.assert_has_calls(
             [mock.call('/dev/sda', mock.sentinel.Force, exc, False),
              mock.call('/dev/sdb', mock.sentinel.Force, exc, True)])
@@ -940,7 +860,7 @@ loop0                                     0"""
                                     'id': '0',
                                     'lun': '0'})
 
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_sysfs_wwn_mpath(self, open_mock):
         wwn = '3600d0230000000000e13955cc3757800'
         cm_open = open_mock.return_value.__enter__.return_value
@@ -961,7 +881,7 @@ loop0                                     0"""
         glob_mock.assert_called_once_with('/dev/disk/by-id/scsi-*')
         get_wwid_mock.assert_called_once_with(mock.sentinel.device_names)
 
-    @mock.patch('six.moves.builtins.open', side_effect=Exception)
+    @mock.patch('builtins.open', side_effect=Exception)
     @mock.patch('glob.glob')
     @mock.patch.object(linuxscsi.LinuxSCSI, 'get_sysfs_wwid')
     def test_get_sysfs_wwn_mpath_exc(self, get_wwid_mock, glob_mock,
@@ -1054,7 +974,7 @@ loop0                                     0"""
               {'wwn_type': 'eui.', 'num_val': '2'},
               {'wwn_type': 'naa.', 'num_val': '3'})
     @ddt.unpack
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_sysfs_wwid(self, open_mock, wwn_type, num_val):
         read_fail = mock.MagicMock()
         read_fail.__enter__.return_value.read.side_effect = IOError
@@ -1069,7 +989,7 @@ loop0                                     0"""
                                     mock.call('/sys/block/sdb/device/wwid'),
                                     mock.call('/sys/block/sdc/device/wwid')])
 
-    @mock.patch('six.moves.builtins.open', side_effect=IOError)
+    @mock.patch('builtins.open', side_effect=IOError)
     def test_get_sysfs_wwid_not_found(self, open_mock):
         res = self.linuxscsi.get_sysfs_wwid(['sda', 'sdb'])
         self.assertEqual('', res)
@@ -1188,10 +1108,6 @@ loop0                                     0"""
         self.linuxscsi.multipath_add_path('/dev/sda')
         self.assertEqual(['multipathd add path /dev/sda'], self.cmds)
 
-    def test_multipath_del_path(self):
-        self.linuxscsi.multipath_del_path('/dev/sda')
-        self.assertEqual(['multipathd del path /dev/sda'], self.cmds)
-
     @ddt.data({'con_props': {}, 'dev_info': {'path': mock.sentinel.path}},
               {'con_props': None, 'dev_info': {'path': mock.sentinel.path}},
               {'con_props': {'device_path': mock.sentinel.device_path},
